summaryrefslogtreecommitdiff
path: root/src/parameters.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/parameters.cpp')
-rw-r--r--src/parameters.cpp18
1 files changed, 16 insertions, 2 deletions
diff --git a/src/parameters.cpp b/src/parameters.cpp
index d31f49c..2fb2eef 100644
--- a/src/parameters.cpp
+++ b/src/parameters.cpp
@@ -13,10 +13,11 @@ namespace Php {
/**
* Parameters
* @param argc Number of arguments
* @param tsrm_ls
*/
-Parameters::Parameters(int argc TSRMLS_DC)
+Parameters::Parameters(zval *this_ptr, int argc TSRMLS_DC) : _this(this_ptr)
{
// reserve plenty of space
reserve(argc);
@@ -33,6 +34,19 @@ Parameters::Parameters(int argc TSRMLS_DC)
}
/**
+ * The the object that is called
+ * @return Base
+ */
+Base *Parameters::object()
+{
+ // get the mixed object
+ MixedObject *obj = (MixedObject *)zend_object_store_get_object(_this TSRMLS_CC);
+
+ // return the CPP object
+ return obj->cpp;
+}
+
+/**
* End of namespace
*/
}
@@ -13,10 +13,11 @@ namespace Php {
/**
* Parameters
- * @param argc Number of arguments
+ * @param this_ptr Pointer to the object
+ * @param argc Number of arguments
* @param tsrm_ls
*/